@@ -88,7 +88,7 @@ class ProfileForm(TendenciBaseForm):
                                 error_messages={'required': 'Last Name is a required field.'})
     email = EmailVerificationField(label=_("Email"),
                                 error_messages={'required': 'Email is a required field.'})
-    email2 = EmailVerificationField(label=_("Email 2"), required=False)
+    email2 = EmailVerificationField(label=_("Secondary Email"), required=False)
 
     initials = forms.CharField(label=_("Initial"), max_length=100, required=False,
                                widget=forms.TextInput(attrs={'size':'10'}))
@@ -325,7 +325,7 @@ class ProfileAdminForm(TendenciBaseForm):
                                 error_messages={'required': 'Last Name is a required field.'})
     email = EmailVerificationField(label=_("Email"),
                                 error_messages={'required': 'Email is a required field.'})
-    email2 = EmailVerificationField(label=_("Email 2"), required=False)
+    email2 = EmailVerificationField(label=_("Secondary Email"), required=False)
 
     username = forms.RegexField(regex=r'^[\w.@+-]+$',
                                 max_length=30,
